summaryrefslogtreecommitdiff
path: root/uvim/src/profiler.c
diff options
context:
space:
mode:
authorMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-03 22:21:25 +0300
committerMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-04 00:23:03 +0300
commit2eae5db069dc171f74cd863487655f6a88e5384d (patch)
tree2d9d05e09978a2a44acbfbb8d651f240df3ca052 /uvim/src/profiler.c
parent473d922faed49241a5d29d9e37dc4819cd512006 (diff)
downloadProject-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.tar.gz
Project-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.zip
NOISSUE rebrand vim to MNV's not Vim
Signed-off-by: Mehmet Samet Duman <yongdohyun@projecttick.org>
Diffstat (limited to 'uvim/src/profiler.c')
-rw-r--r--uvim/src/profiler.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/uvim/src/profiler.c b/uvim/src/profiler.c
index aa127a419f..79f9d92e42 100644
--- a/uvim/src/profiler.c
+++ b/uvim/src/profiler.c
@@ -1,17 +1,17 @@
/* vi:set ts=8 sts=4 sw=4 noet:
*
* VIM - Vi IMproved by Bram Moolenaar
*
* Do ":help uganda" in Vim to read copying and usage conditions.
* Do ":help credits" in Vim to see a list of people who contributed.
* See README.txt for an overview of the Vim source code.
*/
/*
* profiler.c: Vim script profiler
*/
-#include "vim.h"
+#include "mnv.h"
#if defined(FEAT_EVAL)
# if defined(FEAT_PROFILE) || defined(FEAT_RELTIME)
@@ -194,7 +194,7 @@ profile_divide(proftime_T *tm, int count, proftime_T *tm2)
/ count;
tm2->tv_sec = floor(fsec / (float_T)TV_FSEC_SEC);
- tm2->tv_fsec = vim_round(fsec - (tm2->tv_sec * (float_T)TV_FSEC_SEC));
+ tm2->tv_fsec = mnv_round(fsec - (tm2->tv_sec * (float_T)TV_FSEC_SEC));
# endif
}
}
@@ -373,7 +373,7 @@ profile_reset(void)
}
}
- VIM_CLEAR(profile_fname);
+ MNV_CLEAR(profile_fname);
}
/*
@@ -391,11 +391,11 @@ ex_profile(exarg_T *eap)
if (len == 5 && STRNCMP(eap->arg, "start", 5) == 0 && *e != NUL)
{
- VIM_CLEAR(profile_fname);
+ MNV_CLEAR(profile_fname);
profile_fname = expand_env_save_opt(e, TRUE);
do_profiling = PROF_YES;
profile_zero(&prof_wait_time);
- set_vim_var_nr(VV_PROFILING, 1L);
+ set_mnv_var_nr(VV_PROFILING, 1L);
}
else if (do_profiling == PROF_NONE)
emsg(_(e_first_use_profile_start_fname));
@@ -403,7 +403,7 @@ ex_profile(exarg_T *eap)
{
profile_dump();
do_profiling = PROF_NONE;
- set_vim_var_nr(VV_PROFILING, 0L);
+ set_mnv_var_nr(VV_PROFILING, 0L);
profile_reset();
}
else if (STRCMP(eap->arg, "pause") == 0)
@@ -845,7 +845,7 @@ func_dump_profile(FILE *fd)
{
fprintf(fd, " Defined: %s:%ld\n",
p, (long)fp->uf_script_ctx.sc_lnum);
- vim_free(p);
+ mnv_free(p);
}
}
if (fp->uf_tm_count == 1)
@@ -880,7 +880,7 @@ func_dump_profile(FILE *fd)
prof_sort_list(fd, sorttab, st_len, "SELF", TRUE);
}
- vim_free(sorttab);
+ mnv_free(sorttab);
}
/*
@@ -956,7 +956,7 @@ script_dump_profile(FILE *fd)
// continuation lines are listed.
for (i = 0; ; ++i)
{
- if (vim_fgets(IObuff, IOSIZE, sfd))
+ if (mnv_fgets(IObuff, IOSIZE, sfd))
break;
// When a line has been truncated, append NL, taking care
// of multi-byte characters .
@@ -1,17 +1,17 @@
/* vi:set ts=8 sts=4 sw=4 noet:
*
- * VIM - Vi IMproved by Bram Moolenaar
+ * MNV - MNV is not Vim by Bram Moolenaar
*
@@ -1,17 +1,17 @@
*
- * Do ":help uganda" in Vim to read copying and usage conditions.
- * Do ":help credits" in Vim to see a list of people who contributed.
- * See README.txt for an overview of the Vim source code.
+ * Do ":help uganda" in MNV to read copying and usage conditions.
+ * Do ":help credits" in MNV to see a list of people who contributed.
+ * See README.txt for an overview of the MNV source code.
*/
/*
@@ -1,17 +1,17 @@
*/
/*
- * profiler.c: Vim script profiler
+ * profiler.c: MNV script profiler
*/